#if !defined(__DING_RTC_ENGINE_WB_INTERFACE_H__)
#define __DING_RTC_ENGINE_WB_INTERFACE_H__

#include "engine_types.h"
#include "engine_wb_types.h"

namespace ding {
namespace rtc {

/** \defgroup CPP_DingRtcEngineWbManagerCallback 白板管理器回调接口
 *  \ingroup CPP_DingRtcEngine
 * DingRtc 白板管理器监听器。
 */

/** \defgroup CPP_DingRtcEngineWbManager 白板管理器接口
 *  \ingroup CPP_DingRtcEngine
 * DingRtc 白板管理器。
 */


/** \defgroup CPP_DingRtcEngineWB 白板接口
 *  \ingroup CPP_DingRtcEngine
 * DingRtc 白板。
 */

/**
 * @brief 白板基类回调接口。
 */
class RtcEngineWbBaseEventListener {
public:
    virtual ~RtcEngineWbBaseEventListener() = default;

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 加入白板结果。
     * @param result 加入白板结果，成功返回0，失败返回错误码。
     */
    virtual void OnJoinResult(int result) {}

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 离开白板结果。
     * @param result 离开白板结果，成功返回0，失败返回错误码。
     */
    virtual void OnLeaveResult(int result) {}

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 白板用户更新通知。
     * @param action 0: join, 1: leave
     * @param members 变动的用户列表。
     * @param memberCount members数量。
     */
    virtual void OnUserMemberUpdate(int action, WBUserMember *members, int memberCount) {}

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 白板快照结果。
     * @param result 快照结果，成功返回0，失败返回错误码。
     * @param filename 快照文件名。
     */
    virtual void OnSnapshotComplete(int result, const char* filename) {}

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 撤消状态。
     * @param undo 是否允许撤消。
     */
    virtual void OnUndoStatus(bool undo) {}

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 恢复状态。
     * @param redo 是否允许恢复。
     */
    virtual void OnRedoStatus(bool redo) {}

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 缩放比例变化。
     * @param scale 缩放比例。
     */
    virtual void OnZoomScaleChanged(float scale) {}

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 绘制事件。
     * @param event 绘制事件。
     */
    virtual void OnDrawEvent(WBDrawEvent event) {}

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 内容更新
     * @param type 内容更新类型。
     */
    virtual void OnContentUpdate(WBContentUpdateType type) {}

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 页码变化。
     * @param curPage 页码。
     * @param totalPages 总页数。
     */
    virtual void OnPageNumberChanged(WBPageNumber curPage, size_t totalPages) {}

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 白板文档创建结果。
     * @param result 创建结果，成功返回0，失败返回错误码。
     * @param docId 文档ID。
     */
    virtual void OnCreateDoc(int result, String docId) {}

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 白板文档删除结果。
     * @param result 删除结果，成功返回0，失败返回错误码。
     * @param docId 文档ID。
     */
    virtual void OnDeleteDoc(int result, String docId) {}

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 白板文档切换结果。
     * @param result 切换结果，成功返回0，失败返回错误码。
     * @param docId 文档ID。
     */
    virtual void OnSwitchDoc(int result, String docId) {}

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 白板文档保存成图片结果。
     * @param result 保存结果，成功返回0，失败返回错误码。
     * @param docId 文档ID。
     * @param outputDir 输出目录。
     */
    virtual void OnSaveDocComplete(int result, String docId, const char* outputDir) {}

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 白板文档保存进度。
     * @param docId 文档ID。
     * @param current 当前进度（当前页数）。
     * @param total 总进度（总页数）。
     */
    virtual void OnSaveDocProgress(String docId, uint32_t current, uint32_t total) {}

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 收到自定义消息。
     * @param userId 发送方用户ID。
     * @param msg 收到的消息。
     * @param size 消息长度。
     */
    virtual void OnReceiveMessage(const char* userId, const char* msg, size_t size) {}
};

/**
 * @brief 白板回调接口。
 */
class RtcEngineWhiteboardEventListener : public RtcEngineWbBaseEventListener {
public:
    virtual ~RtcEngineWhiteboardEventListener() = default;

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 视角共享开始。
     * @param userId 用户ID。
     */
    virtual void OnVisionShareStarted(const char* userId) {}

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 视角共享结束。
     * @param userId 用户ID。
     */
    virtual void OnVisionShareStopped(const char* userId) {}

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 图像状态变化。
     * @param url 图片URL。
     * @param state 图像状态。
     */
    virtual void OnImageStateChanged(const char* url, WBImageState state) {}

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 文件转码状态。
     * @param docId 文档ID。
     * @param transDocId 转码文档ID。
     * @param state 文件转码状态。
     */
    virtual void OnFileTranscodeState(String docId, const char* transDocId, WBFileTransState state) {}

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 白板文档保存成缩略图结果。
     * @param result 保存结果，成功返回0，失败返回错误码。
     * @param docId 文档ID。
     * @param outputDir 输出目录。
     */
    virtual void OnSaveDocThumbnailComplete(int result, String docId, const char* outputDir) {}

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 白板文档缩略图保存进度。
     * @param docId 文档ID。
     * @param current 当前进度（当前页数）。
     * @param total 总进度（总页数）。
     */
    virtual void OnSaveDocThumbnailProgress(String docId, uint32_t current, uint32_t total) {}
};

/**
 * @brief 标注回调接口。
 */
class RtcEngineAnnotationEventListener : public RtcEngineWbBaseEventListener {
public:
    virtual ~RtcEngineAnnotationEventListener() = default;
};

/**
 * @brief 白板基类。
 */
class RtcEngineWbBase {
public:
    virtual ~RtcEngineWbBase() = default;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 打开白板。
     * @return int 
     */
    virtual int Open(void* window) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 关闭白板。
     * @return int 
     */
    virtual int Close() = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 加入白板。
     * @return int 
     */
    virtual int Join() = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 离开白板。
     * @return int 
     */
    virtual int Leave() = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 结束白板。
     * @return int 
     */
    virtual int Stop() = 0;


    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 设置白板角色。
     * @param role 白板角色。
     * @return int 
     */
    virtual int SetRole(WBRoleType role) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 设置工具类型。
     * @param toolType 工具类型。
     * @return int 
     */
    virtual int SetToolType(WBToolType toolType) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 设置线宽。
     * @param size 线宽。有效值为1-20。
     * @return int 
     */
    virtual int SetLineWidth(int size) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 设置颜色。
     * @param color 颜色。
     * @return int 
     */
    virtual int SetColor(WBColor color) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 设置填充颜色。
     * @param color 填充颜色。
     * @return int 
     */
    virtual int SetFillColor(WBColor color) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 设置填充类型。
     * @param type 填充类型。
     * @return int 
     */
    virtual int SetFillType(WBFillType type) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 设置字体样式。
     * @param style 字体样式。
     * @return int 
     */
    virtual int SetFontStyle(WBFontStyle style) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 设置字体大小。
     * @param size 字体大小。
     * @return int 
     */
    virtual int SetFontSize(int size) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 撤消。
     * @return int 
     */
    virtual int Undo() = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 重做。
     * @return int 
     */
    virtual int Redo() = 0;

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 获取工具类型。
     * @return WBToolType 工具类型。
     */
    virtual WBToolType GetToolType() = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 是否可以撤消。
     * @return bool 
     */
    virtual bool GetUndoStatus() = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 是否可以恢复重做。
     * @return bool 
     */
    virtual bool GetRedoStatus() = 0;

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 添加图章资源。
     * @param stamp 图章。
     * @return int
     */
    virtual int AddStamp(WBStamp stamp) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 设置图章资源。
     * @param stampId 图章资源ID。
     * @return int
     */
    virtual int SetStamp(const char* stampId) = 0;
     
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 设置缩放比例。
     * @param scale 缩放比例。
     * @return int
     */
    virtual int SetZoomScale(float scale) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 设置缩放比例及基于原始中心点缩放后的平移。
     * @param scale 缩放比例。
     * @param tx 缩放后x轴平移。
     * @param ty 缩放后y轴平移。
     * @return int
     */
    virtual int SetZoomScaleWithTranslate(float scale, float tx, float ty) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 设置最小缩放比例。
     * @param scale 缩放比例。
     * @return int
     */
    virtual int SetMinZoomScale(float scale) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 设置最大缩放比例。
     * @param scale 缩放比例。
     * @return int
     */
    virtual int SetMaxZoomScale(float scale) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 获取缩放比例。
     * @return scale 缩放比例。
     */
    virtual float GetZoomScale() = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 获取最小缩放比例。
     * @return scale 缩放比例。
     */
    virtual float GetMinZoomScale() = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 获取最大缩放比例。
     * @return scale 缩放比例。
     */
    virtual float GetMaxZoomScale() = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 设置缩放模式。
     * @param mode 缩放模式。
     * @return int
     */
    virtual int SetScalingMode(WBScalingMode mode) = 0;

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 获取当前白板页码。
     * @return WBPageNumber
     */
    virtual WBPageNumber GetCurrentPageNumber() = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 获取白板页数。
     * @return size_t
     */
    virtual size_t GetTotalNumberOfPages() = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 添加一页到最后。
     * @param autoSwitch 自动切换到新添加的页面。
     * @return int
     */
    virtual int AddPage(bool autoSwitch) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 插入一页到指定页之后。
     * @param pageNo 指定页页码。
     * @param autoSwitch 自动切换到新添加的页面。
     * @return int
     */
    virtual int InsertPage(WBPageNumber pageNo, bool autoSwitch) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 删除一页。
     * @param pageNo 被删除页页码。
     * @param switchNext 切换到删除页的下一页。
     * @note 删除页的默认行为是切换到删除页的前一页。设置switchNext为true改为切换到删除页的下一页。
     * @return int
     */
    virtual int RemovePage(WBPageNumber pageNo, bool switchNext) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 跳转到指定页。
     * @param pageNo 跳转页页码。
     * @return int
     */
    virtual int GotoPage(WBPageNumber pageNo) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 下一页。
     * @return int
     */
    virtual int NextPage() = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 上一页。
     * @return int
     */
    virtual int PrevPage() = 0;

    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 获取当前白板文档ID。
     * @return 当前白板文档ID
     */
    virtual String GetCurrentDocID() = 0;
    /**
     * @ingroup CPP_DingRtcEngineWB
     * @since 3.5
     * @brief 获取白板文档信息。
     * @param docId 白板文档ID。
     * @return 白板文档信息
     */
    virtual WBDocInfo GetDocInfo(String docId) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 获取白板文档列表。
     * @return 白板文档列表
     */
    virtual StringArray GetDocList() = 0;
    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 基于内容创建白板文档。
     * @param contents 文档信息。
     * @param autoSwitch 自动切换到新创建的文档。
     * @return String 白板文档ID。
     * @note contents.transDocId不为空，则查询转码文件信息，忽略contents.urls参数
     */
    virtual String CreateDoc(WBDocContents contents, bool autoSwitch) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 基于外部内容创建白板文档。
     * @param contents 外部文档信息。
     * @param autoSwitch 自动切换到新创建的文档。
     * @return String 白板文档ID。
     */
    virtual String CreateDoc(WBDocExtContents contents, bool autoSwitch) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 删除白板文档。
     * @param docId 白板文档ID。
     * @return int
     */
    virtual int DeleteDoc(String docId) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 切换白板文档。
     * @param docId 白板文档ID。
     * @return int
     */
    virtual int SwitchDoc(String docId) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 复制白板文档页内容。
     * @param srcDocId 源白板文档ID。
     * @param srcPageNum 源白板文档页码。
     * @param dstDocId 目标白板文档ID。
     * @param dstPageNum 目标白板文档页码。
     * @param clearDstPage 是否清空目标白板文档页。
     * @return int
     */
    virtual int CopyDocPage(String srcDocId, WBPageNumber srcPageNum, String dstDocId, WBPageNumber dstPageNum, bool clearDstPage) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 保存白板文档为多张图片。
     * @param docId 白板文档ID。
     * @param outputDir 输出目录
     * @return int
     */
    virtual int SaveDocToImages(String docId, const char* outputDir) = 0;

    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 发送自定义消息给指定用户。
     * @param userId 用户ID。
     * @param msg 要发送的消息。
     * @param size 消息大小，最大不超过16KB。
     * @return int
     */
    virtual int SendUserMessage(const char* userId, const char* msg, size_t size) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 广播消息给所有用户。
     * @param userId 用户ID。
     * @param msg 要发送的消息。
     * @param size 消息大小，最大不超过16KB。
     * @return int
     */
    virtual int BroadcastMessage(const char* msg, size_t size) = 0;

};

/**
 * @brief 白板。
 */
class RtcEngineWhiteboard : public RtcEngineWbBase {
public:
    virtual ~RtcEngineWhiteboard() = default;

    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 设置白板监听器。
     * @param listener 用于接收来自白板的事件
     * @return int 
     */
    virtual int SetEventListener(RtcEngineWhiteboardEventListener *listener) = 0;

    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 设置白板参数。
     * @param option 参数类别。
     * @param param 参数，具体参数需要遵循option定义的参数结构。
     * @param size 参数大小
     * @return int 
     */
    virtual int SetOption(WBOption option, void *param, size_t size) = 0;

    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 清除白板内容。
     * @param param 清除参数。
     * @return int
     */
    virtual int ClearContents(WBClearParam param) = 0;

    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 开始视角共享。
     * @return int 
     */
    virtual int StartShareVision() = 0;

    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 停止视角共享。
     * @return int 
     */
    virtual int StopShareVision() = 0;

    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 开始视角跟随。
     * @return int 
     */
    virtual int StartFollowVision() = 0;

    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 停止视角跟随。
     * @return int 
     */
    virtual int StopFollowVision() = 0;

    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 快照。
     * @param mode
     * @param outputDir 输出目录。
     * @return int 
     */
    virtual int Snapshot(WBSnapshotMode mode, const char* outputDir) = 0;

    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 设置背景色。
     * @param color 背景色。
     * @return int 
     */
    virtual int SetBackgroundColor(WBColor color) = 0;

    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 设置背景图片
     * @param imageUrl 图片地址，可以为本地路径或网络路径
     * @param pageNo 当前文档页码
     * @return int 
     */
    virtual int SetBackgroundImage(const char *imageUrl, WBPageNumber pageNo) = 0;

    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 添加图片
     * @param filePath 图片地址，可以为本地路径或网络路径
     * @return int 
     */
    virtual int AddImageFile(const char *imageUrl) = 0;

    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 保存白板文档为多张缩略图。
     * @param docId 白板文档ID。
     * @param outputDir 输出目录。
     * @return int 
     */
    virtual int SaveDocToThumbnails(String docId, const char* outputDir) = 0;
};

/**
 * @brief 标注。
 */
class RtcEngineAnnotation : public RtcEngineWbBase {
public:
    virtual ~RtcEngineAnnotation() = default;

    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 设置标注监听器。
     * @param listener 用于接收来自标注的事件
     * @return int 
     */
    virtual int SetEventListener(RtcEngineAnnotationEventListener *listener) = 0;

    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 设置标注参数。
     * @param option 参数类别。
     * @param param 参数，具体参数需要遵循option定义的参数结构。
     * @param size 参数大小
     * @return int 
     */
    virtual int SetOption(AnnoOption option, void *param, size_t size) = 0;

    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 清除标注内容。
     * @param param 清除参数。
     * @return int
     */
    virtual int ClearContents(WBClearParam param) = 0;

    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 快照。
     * @param outputDir 输出目录。
     * @return int 
     */
    virtual int Snapshot(const char* outputDir) = 0;

    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 设置标注区域大小。
     * @param w 宽度。
     * @param h 高度。
     * @return int 
     */
    virtual int SetAspectSize(int w, int h) = 0;

    /**
     * @ingroup CPP_DingRtcEngineWb
     * @since 3.5
     * @brief 设置标注窗口位置及大小。
     * @param rect WBRect
     * @return int 
     */
    virtual int SetWindowPos(WBRect rect) = 0;
};

/**
 * @brief 白板管理器回调接口
 * 
 */
class RtcEngineWbManagerListener {
public:
    virtual ~RtcEngineWbManagerListener() = default;

    /**
     * @brief 白板开始。
     * @since 3.5
     * @brief 白板开启回调通知
     */
    virtual void OnWhiteboardStart(const char* whiteboardId, WBConfig cfg) {}
    /**
     * @brief 白板结束。
     * @since 3.5
     * @brief 白板结束回调通知
     */
    virtual void OnWhiteboardStop(const char* whiteboardId) {}
};

/**
 * 
 * @brief 白板管理器。
 */
class RtcEngineWbManager {
public:
    virtual ~RtcEngineWbManager() = default;

    /**
     * @ingroup CPP_DingRtcEngineWbManager
     * @since 3.5
     * @brief 设置白板管理器监听器。
     * @param listener 用于接收来自白板管理器的事件
     * @return int 
     */
    virtual int SetEventListener(RtcEngineWbManagerListener *listener) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWbManager
     * @since 3.5
     * @brief 设置白板缓存路径。
     * @param path 白板缓存路径
     * @return int
     */
    virtual int SetCachePath(const char* path) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWbManager
     * @since 3.5
     * @brief 创建白板对象。
     * @param whiteboardId 白板ID（ding开头的为内部使用字段）
     * @param config 白板配置
     * @return 白板类接口 
     */
    virtual RtcEngineWhiteboard* CreateWhiteboard(const char* whiteboardId, WBConfig config) = 0;
    /**
     * @ingroup CPP_DingRtcEngineWbManager
     * @since 3.5
     * @brief 获取白板对象。
     * @param whiteboardId 白板ID（ding开头的为内部使用字段）
     * @return 白板类接口
     */
    virtual RtcEngineWhiteboard* GetWhiteboard(const char* whiteboardId) = 0;
};

} // namespace rtc
} // namespace ding

#endif /* __DING_RTC_ENGINE_WB_INTERFACE_H__ */
